@@ -1,5 +1,7 @@
 import React from 'react'
 import PropTypes from 'prop-types'
+import getPluginApi from '_/plugin-api'
+import { createErrorMessage } from '_/utils/error-message'
 
 class DataProvider extends React.Component {
   constructor (props) {
@@ -8,7 +10,7 @@ class DataProvider extends React.Component {
       data: null,
       fetchError: null,
       fetchInProgress: false,
-      lastUpdated: null
+      lastUpdated: null,
     }
   }
 
@@ -21,7 +23,7 @@ class DataProvider extends React.Component {
   render () {
     return this.props.children({
       ...this.state,
-      fetchAndUpdateData: () => { this.fetchAndUpdateData() }
+      fetchAndUpdateData: () => { this.fetchAndUpdateData() },
     })
   }
 
@@ -32,7 +34,7 @@ class DataProvider extends React.Component {
         this.onFetchSuccess(data)
       })
       .catch(error => {
-        console.error('DataProvider failed to fetch data', error)
+        getPluginApi().logger().severe('DataProvider failed to fetch data. ' + createErrorMessage(error))
         this.onFetchError(error)
       })
   }
@@ -40,7 +42,7 @@ class DataProvider extends React.Component {
   onFetchStart () {
     this.setState({
       fetchError: null,
-      fetchInProgress: true
+      fetchInProgress: true,
     })
   }
 
@@ -49,7 +51,7 @@ class DataProvider extends React.Component {
       data,
       fetchError: null,
       fetchInProgress: false,
-      lastUpdated: new Date()
+      lastUpdated: new Date(),
     })
   }
 
@@ -58,7 +60,7 @@ class DataProvider extends React.Component {
       data: null,
       fetchError: error,
       fetchInProgress: false,
-      lastUpdated: new Date()
+      lastUpdated: new Date(),
     })
   }
 }
@@ -66,13 +68,13 @@ class DataProvider extends React.Component {
 DataProvider.propTypes = {
   fetchData: PropTypes.func,
   fetchOnMount: PropTypes.bool,
-  children: PropTypes.func
+  children: PropTypes.func,
 }
 
 DataProvider.defaultProps = {
   fetchData: () => Promise.resolve({}),
   fetchOnMount: true,
-  children: () => null
+  children: () => null,
 }
 
 export default DataProvider
